# == Class: zfs
#
# This module installs ZFS from http://zfsonlinux.org/ on Linux hosts. It
# does not manage pools, just the kernel-level support.
#
# === Parameters
#
# [*scrub_frequency*]
#   The frequency at which 'zpool scrub's will be run. If defined, must be
#   one of 'daily', 'weekly', 'monthly'.
#
# === Variables
#
# None.
#
# === Examples
#
#  class { zfs: }
#
# === Authors
#
# Arnaud Gomes-do-Vale <Arnaud.Gomes@ircam.fr>
#
# === Copyright
#
# Copyright 2013 Arnaud Gomes-do-Vale
#
class zfs (
  $scrub_frequency = undef,
) {

  case $osfamily {
    'RedHat': {
      include dkms

      package { 'zfs-release':
        ensure   => present,
        provider => rpm,
        source   => 'http://archive.zfsonlinux.org/epel/zfs-release-1-2.el6.noarch.rpm',
      } ->
      package { 'zfs':
        ensure => present,
        notify => Class['dkms'],
      } ~>
      service { 'zfs':
        ensure    => running,
        enable    => true,
        subscribe => Class['dkms'],
      }
    }
    'Debian': {
      include apt

      apt::source { 'zfsonlinux':
        location => 'http://archive.zfsonlinux.org/debian',
        repos    => 'main',
      } ->
      package { 'zfsonlinux':
        ensure => present,
      } ->
      package { 'debian-zfs':
        ensure => present,
      } ->
      file { '/etc/default/zfs':
        ensure => present,
        source => 'puppet:///modules/zfs/debian/etc_defaults_zfs',
        owner  => 'root',
        group  => 'root',
        mode   => '0444',
      }
    }
    default: {
      fail("Module ${module_name} does not support ${osfamily}.")
    }
  }

  if $scrub_frequency {
    class { 'zfs::scrub':
      frequency => $scrub_frequency,
    }
  }

}
